# ⚠️ WARNING ⚠️

The `CADET` namespace is currently an empty placeholder on PyPI. It is reserved for the [CADET organization](https://github.com/cadet/) and may be used for a CADET meta package in the future. 

For more information on how to install CADET, please refer to the [CADET documentation](https://cadet.github.io/).

Please **remove** 
```bash
pip install cadet
```
from your environment or dependency files. If you encounter any issues, please visit the [CADET-Forum](https://forum.cadet-web.de/).